package com.yiqi.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.system.domain.ManageFactory;

/**
 * 工厂 基本信息Service接口
 *
 * @author ruoyi
 * @date 2023-07-20
 */
public interface IManageFactoryService extends IService<ManageFactory> {
    /**
     * 查询工厂 基本信息
     *
     * @param id 工厂 基本信息主键
     * @return 工厂 基本信息
     */
    public ManageFactory selectYiqiManageFactoryById(Long id);

    /**
     * 查询工厂 基本信息列表
     *
     * @param manageFactory 工厂 基本信息
     * @return 工厂 基本信息集合
     */
    public List<ManageFactory> selectYiqiManageFactoryList(ManageFactory manageFactory);

    /**
     * 新增工厂 基本信息
     *
     * @param manageFactory 工厂 基本信息
     * @return 结果
     */
    public int insertYiqiManageFactory(ManageFactory manageFactory);

    /**
     * 修改工厂 基本信息
     *
     * @param manageFactory 工厂 基本信息
     * @return 结果
     */
    public int updateYiqiManageFactory(ManageFactory manageFactory);

    /**
     * 批量删除工厂 基本信息
     *
     * @param ids 需要删除的工厂 基本信息主键集合
     * @return 结果
     */
    public int deleteYiqiManageFactoryByIds(Long[] ids);

    /**
     * 删除工厂 基本信息信息
     *
     * @param id 工厂 基本信息主键
     * @return 结果
     */
    public int deleteYiqiManageFactoryById(Long id);

    /**
     * 修改工厂状态
     *
     * @param factory 工厂
     * @return 结果
     */
    public int updateFactoryStatus(ManageFactory factory);

}
